@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
 use strict;
-use lib qw('.');
+# use lib qw(lib);
 use CGI::CMS::GUI;
 Body("%PATH%/config/settings.pl");
